@@ -3,7 +3,6 @@
 import os
 import yaml
 import time
-import signal
 import threading
 import json
 import traceback
@@ -13,22 +12,11 @@ import argparse
 import paho.mqtt.client as mqtt
 from . import modules
 from . import config
+from .system_monitor import MonitorSuspend, GracefulKiller
 
 version = importlib.metadata.version(__package__ or __name__)
 
 
-class GracefulKiller:
-    kill_now = False
-
-    def __init__(self):
-        signal.signal(signal.SIGINT, self.exit_gracefully)
-        signal.signal(signal.SIGTERM, self.exit_gracefully)
-
-    def exit_gracefully(self, signum, frame):
-        print("LNXLink stopped by user")
-        self.kill_now = True
-
-
 class LNXlink():
     client = mqtt.Client()
     pref_topic = 'lnxlink'
@@ -39,7 +27,7 @@ class LNXlink():
 
         self.Addons = {}
         for service, addon in modules.parse_modules(self.config['modules']).items():
-            self.Addons[addon.service] = addon()
+            self.Addons[addon.service] = addon(self)
 
         self.setup_mqtt()
 
@@ -90,7 +78,6 @@ class LNXlink():
             self.pref_topic = f"{config['mqtt']['prefix']}/{config['mqtt']['clientId']}"
         self.pref_topic = self.pref_topic.lower()
 
-        print(config)
         config['modules'] = [x.lower().replace('-', '_') for x in config['modules']]
         return config
 
@@ -107,7 +94,7 @@ class LNXlink():
         if self.config['mqtt']['discovery']['enabled']:
             self.setup_discovery()
 
-    def disconnect(self):
+    def disconnect(self, *args):
         print("Disconnected from MQTT.")
         if self.config['mqtt']['lwt']['enabled']:
             self.client.publish(
@@ -122,6 +109,23 @@ class LNXlink():
             pass
         self.client.disconnect()
 
+    def temp_connection_callback(self, status):
+        if self.config['mqtt']['lwt']['enabled']:
+            if status:
+                self.client.publish(
+                    f"{self.pref_topic}/lwt",
+                    payload=self.config['mqtt']['lwt']['disconnectMsg'],
+                    qos=self.config['mqtt']['lwt']['qos'],
+                    retain=self.config['mqtt']['lwt']['retain']
+                )
+            else:
+                self.client.publish(
+                    f"{self.pref_topic}/lwt",
+                    payload=self.config['mqtt']['lwt']['connectMsg'],
+                    qos=self.config['mqtt']['lwt']['qos'],
+                    retain=self.config['mqtt']['lwt']['retain']
+                )
+
     def on_message(self, client, userdata, msg):
         topic = msg.topic.replace(f"{self.pref_topic}/commands/", "")
         message = msg.payload
@@ -130,7 +134,7 @@ class LNXlink():
             message = json.loads(message)
         except Exception as e:
             message = message.decode()
-            print("String could not be converted to JSON")
+            # print("String could not be converted to JSON")
             # traceback.print_exc()
 
         select_service = topic.split('/')
@@ -145,28 +149,33 @@ class LNXlink():
 
     def setup_discovery_monitoring(self, addon, service, discovery_template):
         subtopic = addon.name.lower().replace(' ', '/')
-        topic = f"{self.pref_topic}/{self.config['mqtt']['statsPrefix']}/{subtopic}"
+        state_topic = f"{self.pref_topic}/{self.config['mqtt']['statsPrefix']}/{subtopic}"
 
         discovery = discovery_template.copy()
         discovery['name'] = addon.name.lower().replace(' ', '_')
         discovery['unique_id'] = f"{self.config['mqtt']['clientId']}_{service}"
-        discovery['state_topic'] = topic
+        discovery['state_topic'] = state_topic
         if addon.getInfo.__annotations__.get('return') == dict:
-            discovery['json_attributes_topic'] = topic
-        discovery['icon'] = addon.icon
-        discovery['unit_of_measurement'] = addon.unit
+            discovery['json_attributes_topic'] = state_topic
+        if hasattr(addon, 'icon'):
+            discovery['icon'] = addon.icon
+        if hasattr(addon, 'unit'):
+            discovery['unit_of_measurement'] = addon.unit
+            if addon.unit == 'json':
+                discovery['unit_of_measurement'] = ""
+                discovery['value_template'] = "{{ value_json.status }}"
+                discovery['json_attributes_template'] = "{{ value_json | tojson }}"
+        if hasattr(addon, 'title'):
+            discovery['title'] = addon.title
+        if hasattr(addon, 'entity_picture'):
+            discovery['entity_picture'] = addon.entity_picture
         if hasattr(addon, 'device_class'):
             discovery['device_class'] = addon.device_class
         if hasattr(addon, 'state_class'):
             discovery['state_class'] = addon.state_class
 
-        if addon.unit == 'json':
-            discovery['unit_of_measurement'] = ""
-            discovery['value_template'] = "{{ value_json.status }}"
-            discovery['json_attributes_template'] = "{{ value_json | tojson }}"
-
-        sensor_type = getattr(addon, 'sensor_type', 'sensor')
-        if sensor_type in ['binary_sensor', 'sensor']:
+        sensor_type = getattr(addon, 'sensor_type', None)
+        if sensor_type is not None:
             self.client.publish(
                 f"homeassistant/{sensor_type}/lnxlink/{discovery['unique_id']}/config",
                 payload=json.dumps(discovery),
@@ -174,21 +183,30 @@ class LNXlink():
 
     def setup_discovery_control(self, addon, service, control_name, options, discovery_template):
         subtopic = addon.name.lower().replace(' ', '/')
+        state_topic = f"{self.pref_topic}/{self.config['mqtt']['statsPrefix']}/{subtopic}"
         discovery = discovery_template.copy()
         discovery['name'] = control_name.lower().replace(' ', '_')
         discovery['unique_id'] = f"{self.config['mqtt']['clientId']}_{control_name}"
-        discovery['icon'] = options.get('icon', '')
+        discovery['enabled_by_default'] = options.get('enabled', True)
+        discovery["command_topic"] = f"{self.pref_topic}/commands/{service}/{control_name}/"
+        if 'value_template' in options:
+            discovery["value_template"] = options['value_template']
+        if 'icon' in options:
+            discovery['icon'] = options.get('icon', '')
+
 
         if options['type'] == 'button':
             discovery['state_topic'] = f"{self.pref_topic}/lwt"
-            discovery["command_topic"] = f"{self.pref_topic}/commands/{service}/{control_name}/"
         elif options['type'] == 'switch':
-            discovery["state_topic"] = f"{self.pref_topic}/{self.config['mqtt']['statsPrefix']}/{subtopic}"
-            discovery["command_topic"] = f"{self.pref_topic}/commands/{service}/{control_name}/"
+            discovery["state_topic"] = state_topic
             discovery["payload_off"] = "OFF"
             discovery["payload_on"] = "ON"
+        elif options['type'] == 'text':
+            discovery["state_topic"] = state_topic
         elif options['type'] == 'number':
-            return
+            discovery["state_topic"] = state_topic
+            discovery["min"] = options.get('min', 1)
+            discovery["max"] = options.get('max', 100)
         else:
             return
         self.client.publish(
@@ -221,6 +239,7 @@ class LNXlink():
                 if hasattr(addon, 'exposedControls'):
                     for control_name, options in addon.exposedControls().items():
                         try:
+                            control_name = control_name.lower().replace(' ', '_')
                             self.setup_discovery_control(addon, service, control_name, options, discovery_template)
                         except Exception as e:
                             traceback.print_exc()
@@ -243,9 +262,13 @@ def main():
     lnxlink = LNXlink(config_file)
     lnxlink.monitor_run_thread()
 
-    killer = GracefulKiller()
-    while not killer.kill_now:
+    # Monitor for system changes (Shutdown/Suspend/Sleep)
+    monitor_suspend = MonitorSuspend(lnxlink.temp_connection_callback)
+    monitor_suspend.start()
+    monitor_gracefulkiller = GracefulKiller(lnxlink.temp_connection_callback)
+    while not monitor_gracefulkiller.kill_now:
         time.sleep(1)
+    monitor_suspend.stop()
     lnxlink.disconnect()
 
 
