@@ -1,11 +1,14 @@
 import subprocess
 
+
 class Addon():
-    name = 'Restart'
-    icon = 'mdi:restart'
-    unit = 'button'
+
+    def __init__(self, lnxlink):
+        self.name = 'Restart'
+        self.lnxlink = lnxlink
 
     def startControl(self, topic, data):
+        self.lnxlink.temp_connection_callback(True)
         subprocess.call(["shutdown", "-r", "now"])
 
     def exposedControls(self):
